@@ -39,7 +39,7 @@ class Odds:
         game_url = BASE_URL + f"/a/b/c/d-{self.game_oddsportal_id}/"
         html = get_response(game_url)
         hash_uid = decode_uid(re.findall(r'xhash":"([^"]+)"', html)[0])
-        odds_logger.info({"game_id": {self.game_oddsportal_id}, "hashkey": {hash_uid}, "message": "decode hash key", "function": "get_hash_uid"})
+        odds_logger.info(f"game_id: {self.game_oddsportal_id}, hashkey : {hash_uid}, message: decode hash key, function: get_hash_uid")
         return hash_uid
 
     def get_odds(self, market_type: str):
@@ -222,9 +222,9 @@ class Odds:
             odd_document.time_received = time_received
             try:
                 odd_document.save()
-                odds_logger.info({"gameId": {self.game.game_id}, "database": "oddsportal", "bookmaker": {bookmaker_name}, "message": "successfully inserted", "function": "insert_double_odds_df"})
+                odds_logger.info(f"gameId: {self.game.game_id}, database: oddsportal, bookmaker: {bookmaker_name}, message: Successfully inserted, function: insert_double_odds_df")
             except:
-                odds_logger.error({"gameId": {self.game.game_id}, "database": "oddsportal", "bookmaker": {bookmaker_name}, "message": "failed to insert", "function": "insert_double_odds_df"})
+                odds_logger.error(f"gameId: {self.game.game_id}, database: oddsportal, bookmaker: {bookmaker_name}, message: Failed to insert, function: insert_double_odds_df")
 
             prod_odd_document = OddsProdModel(**self.base_document)
             prod_odd_document.id = document_id
@@ -237,9 +237,9 @@ class Odds:
             prod_odd_document.time_received = time_received
             try:
                 prod_odd_document.save()
-                odds_logger.info({"gameId": {self.game.game_id}, "database": "prod", "bookmaker": {bookmaker_name}, "message": "successfully inserted", "function": "insert_double_odds_df"})
+                odds_logger.info(f"gameId: {self.game.game_id}, database: prod, bookmaker: {bookmaker_name}, message: successfully inserted, function: insert_double_odds_df")
             except:
-                odds_logger.error({"gameId": {self.game.game_id}, "database": "prod", "bookmaker": {bookmaker_name}, "message": "failed to insert", "function": "insert_double_odds_df"})
+                odds_logger.error(f"gameId: {self.game.game_id}, database: prod, bookmaker: {bookmaker_name}, message: failed to insert, function: insert_double_odds_df")
 
             
 
@@ -279,8 +279,8 @@ class Odds:
                 API_BASE_URL + prefix_url + f"1-1-{self.game_oddsportal_id}-{market_code}-{self.hash_uid}.dat?_={time_now_ms}"
             odds_data = json.loads(re.findall(r"\.dat',\s({.*})", get_response(game_api_url))[0])
             if "E" not in odds_data["d"]:
-                odds_logger.info({"game_id": {self.game_oddsportal_id}, "hashkey":{self.hash_uid}, "message": "Successfully decode json odds", "function": "get_odds_json"})
+                odds_logger.info(f"game_id: {self.game_oddsportal_id}, hashkey:{self.hash_uid}, message: Successfully decode json odds, function: get_odds_json")
                 return odds_data
             self.hash_uid = self.get_hash_uid()
-            odds_logger.info({"game_id": {self.game_oddsportal_id}, "hashkey":{self.hash_uid}, "message": "Failed decode json odds", "function": "get_odds_json"})
+            odds_logger.info(f"game_id: {self.game_oddsportal_id}, hashkey:{self.hash_uid}, message: Failed decode json odds, function: get_odds_json")
             time.sleep(2)
